@@ -1,11 +1,13 @@
 package FusionInventory::Agent::Task::Inventory::OS::Generic::Dmidecode;
+
 use strict;
+use warnings;
+
+use English qw(-no_match_vars);
 
 sub isInventoryEnabled {
-  return unless -r "/dev/mem";
-  return unless can_run("dmidecode");
 
-  1;
+    return can_run("dmidecode");
 }
 
 sub doInventory {}
